import type { Adapter } from '@auth/core/adapters';
export type DatabaseProviderType = 'prisma' | 'drizzle' | 'mongodb' | 'postgres' | 'mysql' | 'sqlite' | 'supabase' | 'custom';
export interface BaseDatabaseConfig {
    type: DatabaseProviderType;
    connectionString?: string;
    ssl?: boolean;
}
export interface CustomAdapterConfig extends BaseDatabaseConfig {
    type: 'custom';
    adapter: Adapter;
    getUserByEmail: (email: string) => Promise<any>;
}
export interface PrismaConfig extends BaseDatabaseConfig {
    type: 'prisma';
    client: any;
}
export interface DrizzleConfig extends BaseDatabaseConfig {
    type: 'drizzle';
    client: any;
    schema?: any;
}
export interface MongoDBConfig extends BaseDatabaseConfig {
    type: 'mongodb';
    client: any;
    database?: string;
}
export interface PostgresConfig extends BaseDatabaseConfig {
    type: 'postgres';
    client: any;
}
export interface MySQLConfig extends BaseDatabaseConfig {
    type: 'mysql';
    client: any;
}
export interface SQLiteConfig extends BaseDatabaseConfig {
    type: 'sqlite';
    client: any;
}
export interface SupabaseConfig extends BaseDatabaseConfig {
    type: 'supabase';
    client: any;
    serviceRole?: string;
}
export type DatabaseConfig = PrismaConfig | DrizzleConfig | MongoDBConfig | PostgresConfig | MySQLConfig | SQLiteConfig | SupabaseConfig | CustomAdapterConfig;
export declare const createDatabaseAdapter: (config: DatabaseConfig) => Promise<Adapter | null>;
export declare const getUserByEmail: (config: DatabaseConfig, email: string) => Promise<{} | null>;
