import { optionalImport } from './utils';
// Adapter creation utility
export const createDatabaseAdapter = async (config) => {
    if (!config)
        return null;
    switch (config.type) {
        case 'prisma':
            const { PrismaAdapter } = await optionalImport('@auth/prisma-adapter');
            return PrismaAdapter(config.client);
        case 'custom':
            return config.adapter;
        case 'drizzle':
            const { DrizzleAdapter } = await import('@auth/drizzle-adapter');
            return DrizzleAdapter(config.client, config.schema);
        case 'mongodb':
            const { MongoDBAdapter } = await import('@auth/mongodb-adapter');
            return MongoDBAdapter(config.client, {
                databaseName: config.database
            });
        case 'postgres':
            const { PostgresAdapter } = await import('@auth/pg-adapter');
            return PostgresAdapter(config.client);
        case 'mysql':
            const { MySQLAdapter } = await import('@auth/mysql-adapter');
            return MySQLAdapter(config.client);
        case 'sqlite':
            const { SQLiteAdapter } = await import('@auth/sqlite-adapter');
            return SQLiteAdapter(config.client);
        case 'supabase':
            const { SupabaseAdapter } = await import('@auth/supabase-adapter');
            return SupabaseAdapter(config.client, config.serviceRole);
        default:
            throw new Error(`Unsupported database adapter: ${config.type}`);
    }
};
// TODO Implement Database connection utility
export const getUserByEmail = async (config, email) => {
    if (!config)
        throw new Error('Database configuration is required');
    if (!email)
        return null;
    let user = {};
    switch (config.type) {
        case 'prisma':
            user = await config.client.user.findUnique({ where: { email } });
            console.log(user);
            return user;
        //For now, user has to supply  getUserByEmail function. Hopefully Auth.js would agree to add it to thr adspter specification
        case 'custom':
            user = await config.getUserByEmail(email);
            console.log(user);
            return user;
        //TODO Implement for these adapters
        // case 'drizzle':
        // case 'mongodb':
        // case 'postgres':
        // case 'mysql':
        // case 'sqlite':
        // case 'supabase':
        default:
            throw new Error(`Unsupported database adapter: ${config.type}`);
    }
};
